//---------------------------------------------------------------------------
// Test program for IPC ANumLFRF v1505.22a
// - Load a configuration file (LOAD)
// - set the LF output level (LFPWR)
// - run the session (RUN_MANUAL)
// - send a LF frame (SENDF)
// - wait the frame is sent (FSENT)
// - read and display the 1st received frame (FREAD)
// - stop the session (STOP)
//---------------------------------------------------------------------------
#include <windows.h>
#include <stdio.h>
#include "IPC.h"
#define PATHDLL "IPC.dll"
#define PATHCFG ".\\IPC.cfg"

//---------------------------------------------------------------------------
// GLOBAL VARIABLES
//---------------------------------------------------------------------------
void* hDLL=NULL;                // Instance of DLL
TAPI      API;                  // Pointer on API function (described in API.h)
struct    TAPILFRF sAPILFRF;    // See API.h


//---------------------------------------------------------------------------
// MAIN
//---------------------------------------------------------------------------
int main(int argc, char* argv[])
{
    int iRet=0;
    unsigned char cAPI;
    char aCommand[128];
    int iZ;
    int iN;

    do
    {
        // Load Library
        printf("\n* Loading DLL: %s\n", PATHDLL);
        hDLL=LoadLibrary(PATHDLL);
        if (hDLL==NULL)
        {
            printf("   Error : Loading DLL\n");
            iRet=1;
            break;
        }

        // Get function
        API=(TAPI)GetProcAddress(hDLL, "API");
        if (API==NULL)
        {
            printf("Error : API function not found\n");
            iRet=2;
            break;
        }
        printf ("   OK\n");


        // Necessary to ANumLFRF to be executed in background
        Sleep(2000);

        // Command LOAD
        printf("\n* LOAD\n");
        strcpy(aCommand, "LOAD");
        strcpy(sAPILFRF.StringIn1, PATHCFG);
        cAPI=API(aCommand, (void*)&sAPILFRF);
        printf("   Return=%d\n", cAPI);
        if (cAPI!=0)
            break;

        // Command LFPWR
        printf("\n* LFPWR\n");
        strcpy(aCommand, "LFPWR");
        sAPILFRF.ByteIn1=66;
        cAPI=API(aCommand, (void*)&sAPILFRF);
        printf("   Return=%d\n", cAPI);
        if (cAPI!=0)
            break;

        // Command RUN_MANUAL
        printf("\n* RUN_MANUAL\n");
        strcpy(aCommand, "RUN_MANUAL");
        cAPI=API(aCommand, (void*)&sAPILFRF);
        printf("   Return=%d\n", cAPI);
        if (cAPI!=0)
            break;

        // Command SENDF
        printf("\n* SENDF\n");
        strcpy(aCommand, "SENDF");
        strcpy(sAPILFRF.StringIn1, "TestData");
        strcpy(sAPILFRF.StringIn2, "");
        strcpy(sAPILFRF.StringIn3, "");
        strcpy(sAPILFRF.StringIn4, "");
        sAPILFRF.ByteIn1=200;    // 10 frames
        sAPILFRF.ByteIn2=10;    // Interframe 10ms
        cAPI=API(aCommand, (void*)&sAPILFRF);
        printf("   Return=%d\n", cAPI);
        if (cAPI!=0)
            break;

        // Command FSENT
        do
        {
            strcpy(aCommand, "FSENT");
            cAPI=API(aCommand, (void*)&sAPILFRF);
            if (cAPI!=0)
            {
                printf(" >ERROR");
                getchar();
                break;
            }
        } while (sAPILFRF.ByteOut1==0);
        Sleep(100);
        printf("\n* FSENT\n");
        printf("   Return=%d\n", cAPI);

        // Command FREAD
        printf("\n* FREAD\n");
        strcpy(aCommand, "FREAD");
        cAPI=API(aCommand, (void*)&sAPILFRF);
        printf("   Return=%d\n", cAPI);
        if (cAPI!=0)
            break;
        iN=sAPILFRF.ByteOut1;
        printf("   Nb received frames=%d\n", iN);
        if (iN>0)
        {
            printf("   1st frame=%s\n", sAPILFRF.StringOut1);
        }

        // Command STOP
        printf("\n* STOP\n");
        strcpy(aCommand, "STOP");
        cAPI=API(aCommand, (void*)&sAPILFRF);
        printf("   Return=%d\n", cAPI);
        if (cAPI!=0)
            break;

    } while (0);

    printf("END\n");
    getchar();
    return(iRet);
}









